"superClass"(sommap, method="ward.D", members=NULL, k=NULL,
h=NULL, ...)
"print"(x, ...)
"summary"(object, ...)
"projectIGraph"(object, init.graph, ...)
"plot"(x, type=c("dendrogram", "grid", "hitmap", "lines", "barplot", "boxplot", "mds", "color", "poly.dist", "pie", "graph", "dendro3d", "radar", "projgraph"), plot.var=TRUE, plot.legend=FALSE, add.type=FALSE, ...)somRes objecthclust function.cutree function
(respectively, the number of super-clusters or the height where to cut the
dendrogram).somSC objectinit.graph must be
equal to the number of rows in the original dataset processed by the SOM
(case "korresp" is not handled by this function). In the projected
graph, the vertices are positionned at the center of gravity of the
super-clusters (more details in the section Details below)."dendrogram",
to plot the dendrogram of the clustering. Case "grid" plots the grid
in color according to the super clustering. Case "projgraph" uses an
igraph object passed to the argument variable and plots
the projected graph as defined by the function projectIGraph.somSC.
All other cases are those available in the function plot.somRes
and surimpose the super-clusters over these plots.type="dendrogram", its default value is TRUE.type is either "grid"
or "hitmap" or "mds". Its default value is FALSE.FALSE,
indicating whether you are giving an additional variable to the argument
variable or not. If you do, the function plot.somRes
will be called with the argument what set to "add".plot.somSC: further arguments passed either to
the function plot (case type="dendro") or to
plot.myGrid (case type="grid") or to
plot.somRes (all other cases).superClass function returns an object of class
somSC which is a list of the following elements:
which is a list of the following elements:The projectIGraph.somSC function returns an object of class
igraph with the following attributes: layout which provides the layout of the
projected graph according to the center of gravity of the super-clusters
positionned on the SOM grid;
name and size which, respectively
are the vertex number on the grid and the number of vertexes included in the
corresponding cluster;
weight which gives the number of edges (or the
sum of the weights) between the vertexes of the two corresponding clusters.superClass function can be used in 2 ways:
hclust object:
then, both arguments k and h are not filled.
k
or argument h must be filled. See cutree for details on
these arguments.
The squared distance between prototypes is passed to the algorithm.
summary on a superClass object produces a complete summary of the
results that displays the number of clusters and super-clusters, the clustering
itself and performs ANOVA analyses. For type="numeric" the ANOVA is
performed for each input variable and test the difference of this variable
accross the super-clusters of the map. For type="relational" a
dissimilarity ANOVA is performed (see (Anderson, 2001), except that in the
present version, a crude estimate of the p-value is used which is based on the
Fisher distribution and not on a permutation test.
On plots, the different super classes are identified in the following ways:
type is set among:
"grid" (*, #), "hitmap" (*, #), "lines" (*, #),
"barplot" (*, #), "boxplot", "mds" (*, #),
"dendro3d" (*, #), "graph" (*, #)
type is set among: "color" (*),
"poly.dist" (*, #), "pie" (#), "radar" (#)
In the list above, the charts available for a korresp SOM are marked with
a * whereas those available for a relational SOM are marked with a #.
projectIGraph.somSC produces a projected graph from the
igraph object passed to the argument variable as
described in (Olteanu and Villa-Vialaneix, 2015). The attributes of this graph
are the same than the ones obtained from the SOM map itself in the function
projectIGraph.somRes. plot.somSC used with
type="projgraph" calculates this graph and represents it by positionning
the super-vertexes at the center of gravity of the super-clusters. This feature
can be combined with pie.graph=TRUE to super-impose the information
from an external factor related to the individuals in the original dataset (or,
equivalently, to the vertexes of the graph).
Olteanu, M., Villa-Vialaneix, N. (2015) Using SOMbrero for clustering and visualizing graphs. Journal de la Societe Francaise de Statistique. Under revision.
hclust, cutree, trainSOM,
plot.somResset.seed(11051729)
my.som <- trainSOM(x.data=iris[,1:4])
# choose the number of super-clusters
sc <- superClass(my.som)
plot(sc)
# cut the clustering
sc <- superClass(my.som, k=4)
summary(sc)
plot(sc)
plot(sc, type="hitmap", plot.legend=TRUE)
Run the code above in your browser using DataLab