Learn R Programming

SOMbrero (version 1.2)

sombreroGUI: Graphical Web User Interface for SOMbrero

Description

Starts the SOMbrero GUI

Usage

sombreroGUI()

Arguments

Value

system browser. This interface is more lickely to work properly with Firefox http://www.mozilla.org/fr/firefox/new/. In case Firefox is not your default browser, copy/paste http://localhost:8100 into the address bar.

References

Boelaert J., Bendhaiba L., Olteanu M., Villa-Vialaneix N. (2014) SOMbrero: an R package for numeric and non-numeric self-organizing maps. In: T. Villmann, F.M. Schleif, M. Kaden & M. Lange (Eds.), Advances in Self-Organizing Maps and Learning Vector Quantization (Proceedings of WSOM 2014) (Vol. 295, 219-228). Mittweida, Germany: Berlin Springer Verlag.

RStudio and Inc. (2013). shiny: Web Application Framework for R. R package version 0.7.0. http://cran.r-project.org/package=shiny